#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2015  Marek Marczykowski-Górecki
#                       <marmarek@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#

Name:		qubes-kernel-vm-support
Version:	4.1.1
Release:	1%{?dist}
Summary:	Qubes VM initramfs modules
Source0:    qubes-utils-%{version}.tar.gz

Group:		Qubes
Vendor:     Invisible Things Lab
License:	GPL v2 only
URL:		http://www.qubes-os.org

Requires:	dracut

%description
This package contains:
1. Dracut module required to setup Qubes VM root filesystem. This package is
needed in VM only when the VM uses its own kernel (via pvgrub or so). Otherwise
initrd is provided by dom0.

%prep
%setup -q -n qubes-utils-%{version}

%install
make install-fedora-kernel-support DESTDIR=%{buildroot}

%files
/usr/lib/dracut/modules.d/90qubes-vm
/usr/lib/dracut/modules.d/90qubes-vm-modules
/usr/lib/dracut/modules.d/90qubes-vm-simple
/usr/lib/dracut/modules.d/80xen-scrub-pages
/usr/sbin/qubes-prepare-vm-kernel
%config(noreplace) /etc/default/grub.qubes-kernel-vm-support

%triggerin -- grub2-tools
if ! grep -q '/etc/default/grub.qubes-kernel-vm-support$' /etc/default/grub 2>/dev/null; then
    # do not keep Qubes-related settings directly in user-controlled config,
    # include another file
    echo '. /etc/default/grub.qubes-kernel-vm-support' >> /etc/default/grub
fi

%preun
if [ $1 -eq 0 ]; then
    if grep -q '/etc/default/grub.qubes-kernel-vm-support$' /etc/default/grub 2>/dev/null; then
        sed -i -e '/grub.qubes-kernel-vm-support$/d' /etc/default/grub
    fi
fi

%posttrans

# Rebuild all initramfs images to include updated modules
if [ -r /usr/share/qubes/marker-vm ] && [ -x /usr/bin/dracut ]; then
    ret=0
    for img in /boot/initramfs-*.img; do
        kver="${img#*initramfs-}"
        kver="${kver%.img}"
        dracut -f "$img" "$kver" || ret=$?
    done
    if [ "$ret" -eq 0 ]; then
        # "milestone" initramfs update version:
        # 1 - addition of xen scrub_pages enabling code
        echo 1 > /var/lib/qubes/initramfs-updated
    fi
fi

%changelog
* Mon Jun 10 2019 Qubes OS Team <qubes-devel@groups.google.com>
- For complete changelog see: https://github.com/QubesOS/qubes-linux-utils

* Mon Jun 10 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 81c64d5
- version 4.1.1

* Sun Jun 09 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8418891
- initrd: mount / rw for the overlayfs setup time

* Sat Jun 08 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 66a6e33
- version 4.1.0

* Thu Jun 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d48e497
- travis: update to R4.1

* Thu Jun 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c046807
- Remove u2mfn module

* Thu Jun 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 7486078
- Remove qrexec related files

* Thu Jun 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 042b671
- version 4.0.24

* Thu Jun 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9c6c825
- initramfs: use overlayfs for /lib/modules, if available

* Wed Jun 05 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 90641b0
- Merge remote-tracking branch 'origin/pr/40'

* Wed Jun 05 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e7c90c7
- Declare u2mfn module version, skip build for qubes kernels

* Wed Jun 05 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - f365d7c
- travis: remove older Fedora releases and add Fedora 30

* Tue Jun 04 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 2b84113
- travis: switch to xenial

* Tue Jun 04 2019 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - e00a64a
- python3: use macro pkgversion

* Mon Feb 25 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 24a25cc
- version 4.0.23

* Mon Feb 25 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - de2150e
- Add xen_scrub_pages=0 kernel option only if initramfs was rebuilt

* Mon Feb 25 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ad790a5
- Really install xen-scrub-pages dracut module

* Tue Feb 19 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 2c69601
- Do not use /proc/xen for detecting dom0 anymore

* Sat Feb 16 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4fe08d3
- Adjust permissions of /dev/xen/hypercall

* Fri Feb 15 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - da61cb7
- dracut: add a flag file indicating scrub-pages option support

* Wed Feb 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5eb526d
- dracut: fix checking for "Root filesystem" label, improve udev sync

* Wed Feb 06 2019 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 456fe99
- Disable scrubbing memory pages during initial balloon down

* Mon Oct 29 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 14be8aa
- version 4.0.22

* Fri Oct 26 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4543ab1
- tests: skip the other img converter test too

* Wed Oct 17 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4bfd10b
- imgconverter: allow icons up to 2048x2048

* Tue Oct 16 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0255f4d
- tests: skip img converter test if qubes-img-converter is not installed

* Tue Oct 09 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e2d7f08
- version 4.0.21

* Mon Oct 08 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 76fa9c9
- travis: update Fedora and Debian versions

* Tue Oct 02 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3ca9f13
- rpm: adjust for fc29

* Thu Sep 06 2018 Rusty Bird <rustybird@net-c.com> - 6cd4a1b
- Order qubes-meminfo-writer-dom0 before systemd-user-sessions

* Tue Jul 03 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ab7ca7b
- version 4.0.20

* Wed Jun 13 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f7b8a79
- udev: create /dev/mapper/dmroot -> xvda3 symlink when its mounted directly

* Wed May 02 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 915c8f0
- version 4.0.19

* Tue May 01 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 645d23b
- travis: add centos7

* Tue May 01 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 89776c7
- rpm: use proper macros for systemd handling

* Sat Apr 21 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 4157f91
- version 4.0.18

* Sat Apr 21 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - cf64388
- travis: update Fedora versions

* Sat Apr 21 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 0df0d23
- Merge remote-tracking branch 'qubesos/pr/34'

* Fri Apr 20 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9eafc65
- udev: don't call udev-block-add-change for devices excluded by other rules

* Sat Apr 07 2018 Frédéric Pierret <frederic.epitre@orange.fr> - f049d63
- spec.in: add changelog placeholder

* Sat Apr 07 2018 Frédéric Pierret <frederic.epitre@orange.fr> - 2b3b684
- Fix debug symbols

* Sat Apr 07 2018 Frédéric Pierret <frederic.epitre@orange.fr> - a716102
- Remove _builddir

* Sat Apr 07 2018 Frédéric Pierret <frederic.epitre@orange.fr> - 0630c17
- Makefile.builder: currently disable Mock

* Tue Apr 03 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 84c9ae4
- rpm: preparation for src.rpm building

* Tue Feb 27 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 610e7d8
- version 4.0.17

* Sun Feb 25 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 258b792
- Merge remote-tracking branch 'qubesos/pr/33'

* Thu Feb 22 2018 Frédéric Pierret <frederic.epitre@orange.fr> - d60964e
- drop busybox dependance

* Thu Feb 22 2018 Frédéric Pierret <frederic.epitre@orange.fr> - 2f511d4
- centos: fix python packages names

* Thu Feb 22 2018 Frédéric Pierret <frederic.epitre@orange.fr> - e3179e0
- Remove busybox as it is not provided in RHEL7 anymore

* Wed Feb 21 2018 Frédéric Pierret <frederic.epitre@orange.fr> - d1ce12f
- Fix python3 package names with respect to CentOS for consistency with python34 names

* Tue Feb 20 2018 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ff36d11
- version 4.0.16

